#
# spec file for package stardict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1500
%define espeakdev espeak-ng-compat-devel
%else
%define espeakdev espeak-devel
%endif
Name:           stardict
Version:        3.0.7
Release:        1.3
Summary:        A powerful cross-platform dictionary written in GTK+3
License:        GPL-3.0-only
Group:          Productivity/Office/Dictionary
URL:            https://stardict-4.sourceforge.net/
Source0:        http://download.sourceforge.net/stardict-4/%{name}-%{version}-2-src.7z#/%{name}-%{version}.7z
# PATCH-FIX-OPENSUSE stardict-3.0.3-fix-path-for-sounds.patch -- adjust default path for sound files
Patch0:         stardict-3.0.3-fix-path-for-sounds.patch
# PATCH-FIX-OPENSUSE stardict-3.0.3-improve-desktop-file.patch -- add GenericName entry
Patch1:         stardict-3.0.3-improve-desktop-file.patch
# PATCH-FIX-UPSTREAM stardict-drop-autotools-gconf.patch badshah400@gmail.com -- Drop unnecessary and no longer supported autotools gconf macro
Patch2:         stardict-drop-autotools-gconf.patch
BuildRequires:  %{espeakdev}
BuildRequires:  7zip
BuildRequires:  fdupes
BuildRequires:  flite-devel
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  sgml-skel
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(gnome-doc-utils)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(zlib)

%description
StarDict is a cross-platform and international dictionary written in GTK+3.

It has features such as "Glob-style pattern matching", "Scan
selection word" and "Fuzzy query".

%lang_package

%prep
%autosetup -p1

# Remove unneeded sigc++ header files to make it sure
# that we are using system-wide libsigc++
find dict/src/sigc++* -name "*.h" -or -name "*.cc" -delete

%build
# Hack: There are innumerable `const char *` to `char *` conversions
export CFLAGS="%{optflags} -fpermissive"
export CXXFLAGS="%{optflags} -fpermissive"
NOCONFIGURE=1 ./autogen.sh
%configure \
           --disable-dictdotcn \
           --disable-festival \
           --disable-gnome-support \
           --disable-gucharmap \
           --disable-schemas-install \
           --disable-scrollkeeper \
           --disable-tools
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

# Move metadata file to correct dir
mkdir -p %{buildroot}%{_datadir}/metainfo
mv %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml \
   %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml

# save space, create symlinks for identical files
%fdupes -s %{buildroot}

%files -f %{name}.lang
%license COPYING
%doc dict/doc/FAQ dict/doc/HACKING dict/doc/HowToCreateDictionary dict/doc/StarDictFileFormat dict/doc/Translation dict/AUTHORS dict/ChangeLog dict/README
%{_libdir}/stardict
%{_bindir}/*
%{_mandir}/man1/stardict-editor.1%{?ext_man}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/stardict/
%{_datadir}/metainfo/*.appdata.xml
%{_mandir}/man1/stardict.1%{?ext_man}

%changelog
* Mon Dec 16 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.7:
  * Port to gtk3.
  * Add some babylon dictionaries.
  * Add some BigDict dictionaries.
  * Add some PowerWord dictionaries.
  * Stardict_client add md5 salt feature and RSA encrypt feature.
  * Add fortune and cal plugins.
  * Add info plugin.
  * Add flite TTS plugin.
  * Add YouDao.com netdict plugin.
  * Add multi-cmd plugin.
  * Many small changes.
  * Updated translations.
- Rebase patches to apply cleanly and with -p1:
  * stardict-3.0.3-fix-path-for-sounds.patch
  * stardict-3.0.3-improve-desktop-file.patch
- Drop stardict-3.0.5-enable-gtk3.patch incorporated upstream.
- Add stardict-drop-autotools-gconf.patch: Drop an obsolete gconf2
  macro from autotools scripts.
- Miscellaneous specfile cleanups (spec-cleaner).
- Hack: Build with `-fpermissive` CFLAGS to avoid innumerable
  `const char *` to `char *` casts due to ongoing transition to
  gtk3.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Jun 12 2020 andy great <andythe_great@pm.me>
- Update to version 3.0.6.
  * Update stardict_powerword_parsedata.cpp
  * Small text changes.
- Clean up spec file.
* Thu Mar 22 2018 jengelh@inai.de
- Remove filler wording from description.
- Don't bother with xargs, use find delete directly.
* Wed Mar 21 2018 aloisio@gmx.com
- Use espeak-ng when available
- Remove espeak and enchant runtime dependencies (rpm will require
  each library automatically)
* Mon Aug 18 2014 kkirill@opensuse.org
- update to 3.0.5
  + update Kazakh and Russian translations
  + stardict-advertisement-plugin comes back
  + 'P' dictionary content type identifier comes back
  + add don't load bad dict option
  + add show_ads checkbox for update-info-plugin
- compile with --disable-gnome-support since GNOME 2 is obsoleted
- drop upstreamed patches:
  + stardict-3.0.3-wrong-memset.patch
  + stardict-3.0.3-zlib-update.patch
- add patch to enable gtk3 build:
  + stardict-3.0.5-enable-gtk3.patch
* Sat Sep  7 2013 kkirill@opensuse.org
- updated Russian translation (from rev. 58222e24e201)
* Thu May  2 2013 crrodriguez@opensuse.org
- fix build with new automake
* Wed Jan 16 2013 bili@suse.com
- updated to 3.0.4.
  - Update default main window size.
  - Add go back and go forward button.
  - Configure.ac mysql-config fix and other small fixes.
- Delete the patches which are fixed in upstream.
  - stardict-3.0.3-gcc46.patch
  - stardict-3.0.3-NetDictRequest.patch
  - stardict-3.0.3-fix-glib_h-include.patch
* Thu Jun 14 2012 coolo@suse.com
- compile with latest zlib
* Tue Jan 24 2012 kkirill@opensuse.org
- added stardict-3.0.3-fix-glib_h-include.patch to include only
  glib.h
* Tue Dec 27 2011 idonmez@suse.com
- added stardict-3.0.3-wrong-memset.patch to fix wrong size
  parameter in memset call
* Tue Nov 29 2011 swyear@gmail.com
- added stardict-3.0.3-NetDictRequest.patch to fix crash with
  ERROR:compositelookup.cpp:53. Fixed bnc#736368
* Tue Sep  6 2011 kirill.kirillov@gmail.com
- added stardict-3.0.3-improve-desktop-file.patch
- added ru.po (fixed mistakes in Russian translation)
* Mon Sep  5 2011 kirill.kirillov@gmail.com
- added stardict-3.0.3-gcc46.patch
- removed gucharmap dependency
- fixed license tag
- fixed spurious-executable-perm RPMLINT warning
- cleaned spec using spec-cleaner
* Mon Apr  4 2011 kirill.kirillov@gmail.com
- updated to 3.0.3
- dropped festival
* Wed Jan 12 2011 kirill.kirillov@gmail.com
- Adjust default path for sound files:
  Needed by stardict-sounds-wyabdcrealpeopletts package
* Tue Jan 26 2010 embar@users.berlios.de
- Fix to avoid hang if pulseaudio not installed
- Include Lithuanian translation
* Tue May 26 2009 xwhu@suse.de
- Fix to avoid compile errors
* Tue Mar 24 2009 xwhu@suse.de
- Update po file for Russian
- Disable netupdatee advertisement by default
* Fri Mar 20 2009 crrodriguez@suse.de
- fix build with GCC 4.4
* Wed Jan 14 2009 xwhu@suse.de
- bnc#465161, stardict crashes when gethostbyname_r failes.
* Mon Sep 29 2008 lrupp@suse.de
- fix build on distributions with old Gucharmap library
* Wed Sep 17 2008 lrupp@suse.de
- fix buildrequires
- mark stardict.schemas as %%config
* Thu Jul 10 2008 maw@suse.de
- Add stardict-gucharmap.patch and run autoreconf -fi to reenable
  gucharmap functionality.
* Thu Jul 10 2008 xwhu@suse.de
- fix configure.in for festival
* Sat Jun 28 2008 xwhu@suse.de
- disable gucharmap due to API change
* Tue Jan 29 2008 lrupp@suse.de
- fix some compiler issues with gcc4.3:
  stardict-3.0.1-includes.patch
- remove unneeded sigc++ header
- added stardict-transparent_trayicon.patch from Fedora
* Tue Jan 22 2008 kirill.kirillov@gmail.com
- removed annoying adware
  (--disable-advertisement)
* Sat Jan 12 2008 kirill.kirillov@gmail.com
- update to 3.0.1
  + dictdotcn plugin was added
  + wordnet plugin was added
  + regex query support was added
  + QQWry plugin was added
  + many other changes were made
- added stardict-3.0.1-festival.h-path-fix.patch
- added separate stardict.desktop source
* Wed Oct 31 2007 lrupp@suse.de
- update to 3.0.0
  + Network dictionaries support.
  + Plugin system.
  + Full-text translation.
  + Pronounce word by TTS engine.
  + Preliminary WikiPedia dictionary support.
  + More powerful dictionary management.
  + Babylon dictionaries convertion.
  + Many other changes.
- removed upstreamed stardict-2.4.8-private_function.patch
* Mon Oct 29 2007 xwhu@novell.com
- Fix header files compatibility issues with gcc 4.3
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Jun 18 2007 lrupp@suse.de
- update to 2.4.8
  + KingSoft PowerWord support
  + Synonym support
  + Sort word list by collate function support
  + dictionaries from XDXF project available for stardict, too
  + cfdict dictionary support
  + Full-text search
  + Evgeniy's patches for special character search and other changes
  + Export word or text to file, thanks Mao-Yuan Kao
  + Pango text markup language support
  + Sparse wordoffset index: This make StarDict's memory usage
    become very low
  + Add new tools: stardict_verify, treedict2dir, tabfile
  + added many dictionaries and translations
- adapt patches
- added stardict-2.4.8-private_function.patch
- remove provides %%{name} = 2.4
- use fdupes to save space
- fixed desktop file: works now on other windowmanagers, too
- use more macros in specfile and allow builds on older distris
- added documentation files
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Thu Mar 15 2007 sbrabec@suse.cz
- Fixed schemas installation, spec file cleanup (#254850).
* Mon Mar 12 2007 anonymous@anonymous
- Use gconf_schemas_prereq
* Mon Jan  8 2007 ro@suse.de
- fix localstatedir
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Sat Oct  7 2006 aj@suse.de
- Cleanup BuildRequires.
- Build with RPM_OPT_FLAGS.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 xwhu@novell.com
- Initial build of 2.4.5
